body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;background-color:#f5f7fa;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;margin:0}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}.ant-layout-header{align-items:center;background:linear-gradient(90deg,#001529,#003a70);color:#fff;display:flex;padding:0 24px}.ant-layout-content{background:linear-gradient(135deg,#f5f7fa,#f0f2f5);padding:32px}.layout{min-height:100vh}.logo{font-size:20px;font-weight:600;margin-right:24px}.logo a{align-items:center;color:#fff;display:flex;text-decoration:none}.site-layout-content{margin:0 auto;max-width:1200px;padding:24px}.ant-menu-dark.ant-menu-horizontal>.ant-menu-item{border-radius:4px;margin:0 4px;transition:all .3s}.ant-menu-dark.ant-menu-horizontal>.ant-menu-item-selected{background-color:#ffffff26}.ant-menu-dark.ant-menu-horizontal>.ant-menu-item>a{color:#ffffffd9;padding:0 16px}.ant-menu-dark.ant-menu-horizontal>.ant-menu-item-selected>a{color:#fff}.ant-card-head{background:linear-gradient(90deg,#fafafa,#f5f5f5);border-bottom:1px solid #f0f0f0;padding:16px 24px}.ant-card-head-title{color:#000000d9;font-size:18px;font-weight:600}.ant-table-thead>tr>th{background-color:#fafafa;font-weight:600;padding:16px}.ant-alert{border-radius:8px;box-shadow:0 2px 8px #00000026}.ant-alert-message{font-weight:600}
/*# sourceMappingURL=main.90b51683.css.map*/